#[repr(u8)]pub enum AlphaCtrl {
EMBEDDED = 0,
OVERRIDE = 1,
MULTIPLY = 2,
ROPS = 3,
}Variants
EMBEDDED = 0
Indicates that the AS pixel alpha value will be used to blend the AS with PS. The ALPHA field is ignored.
OVERRIDE = 1
Indicates that the value in the ALPHA field should be used instead of the alpha values present in the input pixels.
MULTIPLY = 2
Indicates that the value in the ALPHA field should be used to scale all pixel alpha values. Each pixel alpha is multiplied by the value in the ALPHA field.
ROPS = 3
Enable ROPs. The ROP field indicates an operation to be performed on the alpha surface and PS pixels.
Implementations