#[repr(u8)]pub enum CtrlEnRepeat {
COMPLETE = 0,
REPEAT = 1,
}Variants
COMPLETE = 0
PXP will complete the process and enter the idle state ready to accept the next frame to be processed
REPEAT = 1
PXP will repeat based on the current configuration register settings
Implementations
Sourceimpl CtrlEnRepeat
impl CtrlEnRepeat